sqlobject.tests.test_SQLMultipleJoin module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_SQLMultipleJoin module

class `sqlobject.tests.test_SQLMultipleJoin.` `RFighter`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = rfighter
  property `name`
  property `power`
  `q` = rfighter
  property `race`
  property `raceID`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_SQLMultipleJoin.RFighter`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'rfighter'

class `sqlobject.tests.test_SQLMultipleJoin.` `Race`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `fightersAsList`
  property `fightersAsSResult`
  `j` = race
  property `name`
  `q` = race
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.MultipleJoin object>, <sqlobject.joins.SQLMultipleJoin object>]
    `joins` = [<sqlobject.joins.SOSQLMultipleJoin object>, <sqlobject.joins.SOMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_SQLMultipleJoin.Race`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'race'

`sqlobject.tests.test_SQLMultipleJoin.` `createAllTables`()

`sqlobject.tests.test_SQLMultipleJoin.` `test_1`()

`sqlobject.tests.test_SQLMultipleJoin.` `test_multiple_join_transaction`()